==> 389-ds-base-1.2.6.a1.tar.bz2: 389-ds-base-1.2.6.a1/ldap/servers/plugins/chainingdb/cb_schema.c <==
/** BEGIN COPYRIGHT BLOCK
 * This Program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation; version 2 of the License.
 * 
 * This Program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * this Program; if not, write to the Free Software Foundation, Inc., 59 Temple
 * Place, Suite 330, Boston, MA 02111-1307 USA.
 * 
 * In addition, as a special exception, Red Hat, Inc. gives You the additional
 * right to link the code of this Program with code not covered under the GNU
 * General Public License ("Non-GPL Code") and to distribute linked combinations
 * including the two, subject to the limitations in this paragraph. Non-GPL Code
 * permitted under this exception must only link to the code of this Program
 * through those well defined interfaces identified in the file named EXCEPTION
 * found in the source code files (the "Approved Interfaces"). The files of
 * Non-GPL Code may instantiate templates or use macros or inline functions from
 * the Approved Interfaces without causing the resulting work to be covered by
 * the GNU General Public License. Only Red Hat, Inc. may make changes or
 * additions to the list of Approved Interfaces. You must obey the GNU General
 * Public License in all respects for all of the Program code and other code used
 * in conjunction with the Program except the Non-GPL Code covered by this
 * exception. If you modify this file, you may extend this exception to your
 * version of the file, but you are not obligated to do so. If you do not wish to
 * provide this exception without modification, you must delete this exception
 * statement from your version and license this file solely under the GPL without
 * exception. 
 * 
 * 
 * Copyright (C) 2001 Sun Microsystems, Inc. Used by permission.
 * Copyright (C) 2005 Red Hat, Inc.
 * All rights reserved.
 * END COPYRIGHT BLOCK **/

#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include "cb.h"

void cb_eliminate_illegal_attributes(cb_backend_instance * inst, Slapi_Entry * e) {

        /* get rid of illegal attributes before sending op to the   */
	/* farm server.	(Add)				                */
		
	int 		rc,j;
	Slapi_Attr 	*attr=NULL;
	char 		*tobefreed=NULL;

	if (inst->illegal_attributes != NULL ) {       /* Unlikely to happen */

		PR_RWLock_Wlock(inst->rwl_config_lock); 
 
                for (j=0; inst->illegal_attributes[j]; j++) { 
			char * aType=NULL;
			rc=slapi_entry_first_attr(e,&attr);
			while (rc==0) {
        			if (tobefreed) {
					slapi_entry_attr_delete( e, tobefreed);
					tobefreed=NULL;
				}
				slapi_attr_get_type(attr,&aType);
                        	if (aType && slapi_attr_types_equivalent(inst->illegal_attributes[j],aType)) {
					tobefreed=aType;
					slapi_log_error( SLAPI_LOG_PLUGIN, CB_PLUGIN_SUBSYSTEM,
						"attribute <%s> not forwarded.\n",aType);
				}
                		rc = slapi_entry_next_attr(e, attr, &attr);
			}
       			if (tobefreed) {
				slapi_entry_attr_delete( e, tobefreed);
				tobefreed=NULL;
			}
		}

		PR_RWLock_Unlock(inst->rwl_config_lock); 
	}
}

==> 389-ds-base_1.3.2.16.orig.tar.bz2: 389-ds-base-1.3.2.16/ldap/servers/plugins/chainingdb/cb_schema.c <==
/** BEGIN COPYRIGHT BLOCK
 * This Program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation; version 2 of the License.
 * 
 * This Program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * this Program; if not, write to the Free Software Foundation, Inc., 59 Temple
 * Place, Suite 330, Boston, MA 02111-1307 USA.
 * 
 * In addition, as a special exception, Red Hat, Inc. gives You the additional
 * right to link the code of this Program with code not covered under the GNU
 * General Public License ("Non-GPL Code") and to distribute linked combinations
 * including the two, subject to the limitations in this paragraph. Non-GPL Code
 * permitted under this exception must only link to the code of this Program
 * through those well defined interfaces identified in the file named EXCEPTION
 * found in the source code files (the "Approved Interfaces"). The files of
 * Non-GPL Code may instantiate templates or use macros or inline functions from
 * the Approved Interfaces without causing the resulting work to be covered by
 * the GNU General Public License. Only Red Hat, Inc. may make changes or
 * additions to the list of Approved Interfaces. You must obey the GNU General
 * Public License in all respects for all of the Program code and other code used
 * in conjunction with the Program except the Non-GPL Code covered by this
 * exception. If you modify this file, you may extend this exception to your
 * version of the file, but you are not obligated to do so. If you do not wish to
 * provide this exception without modification, you must delete this exception
 * statement from your version and license this file solely under the GPL without
 * exception. 
 * 
 * 
 * Copyright (C) 2001 Sun Microsystems, Inc. Used by permission.
 * Copyright (C) 2005 Red Hat, Inc.
 * All rights reserved.
 * END COPYRIGHT BLOCK **/

#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include "cb.h"

void cb_eliminate_illegal_attributes(cb_backend_instance * inst, Slapi_Entry * e) {

        /* get rid of illegal attributes before sending op to the   */
	/* farm server.	(Add)				                */
		
	int 		rc,j;
	Slapi_Attr 	*attr=NULL;
	char 		*tobefreed=NULL;

	if (inst->illegal_attributes != NULL ) {       /* Unlikely to happen */

		slapi_rwlock_wrlock(inst->rwl_config_lock); 
 
                for (j=0; inst->illegal_attributes[j]; j++) { 
			char * aType=NULL;
			rc=slapi_entry_first_attr(e,&attr);
			while (rc==0) {
        			if (tobefreed) {
					slapi_entry_attr_delete( e, tobefreed);
					tobefreed=NULL;
				}
				slapi_attr_get_type(attr,&aType);
                        	if (aType && slapi_attr_types_equivalent(inst->illegal_attributes[j],aType)) {
					tobefreed=aType;
					slapi_log_error( SLAPI_LOG_PLUGIN, CB_PLUGIN_SUBSYSTEM,
						"attribute <%s> not forwarded.\n",aType);
				}
                		rc = slapi_entry_next_attr(e, attr, &attr);
			}
       			if (tobefreed) {
				slapi_entry_attr_delete( e, tobefreed);
				tobefreed=NULL;
			}
		}

		slapi_rwlock_unlock(inst->rwl_config_lock); 
	}
}
